/*
 * Ratiometric Frequency Counter
 *
 * config.h - configurable options
 *
 * (c) Axel (XL) Schwenke, axel.schwenke@gmx.net
 *
 * $Id: config.h 126 2011-03-07 13:58:36Z schwenke $
 */

#ifndef CONFIG_H
#define CONFIG_H

/*
 * some general settings
 */
#define VERSION   "V1.4 (c)XL"    /* version string to display */
#define MINCYCLES (4*1024*1024L)  /* min number of fref cycles */
#define SLEEP     1               /* sleep in wait loops */
#define WDT       1               /* enable hardware watchdog */


/*
 * customization of displayed data
 * pick one of the predefined defaults or create your own
 */

#define default_1x10 1
#define default_1x16 2
#define default_2x16 3
#define de0508_2x16  4
#define debug_2x16  99

#define CUSTOMIZATION de0508_2x16


#if CUSTOMIZATION == default_1x10

#define SHOW_GREETING show_greeting_1x10
#define SHOW_RESULT   show_result_1x10
#define PHASE1()
#define PHASE2()
#define PHASE3()
#define UNDERFLOW()   lcd_gotoxy(4,1); lcd_putc('Z')
#define IS_VALID()
#define LCD_LINES     2
#define LCD_DISP_LEN  5
#define DEBUG         0

#elif CUSTOMIZATION == default_1x16

#define SHOW_GREETING show_greeting_1x16
#define SHOW_RESULT   show_result_1x16
#define PHASE1()      lcd_gotoxy(6,1); lcd_putc('.');
#define PHASE2()      lcd_gotoxy(6,1); lcd_putc('o');
#define PHASE3()      lcd_gotoxy(6,1); lcd_putc('O');
#define UNDERFLOW()   lcd_gotoxy(7,1); lcd_putc('U')
#define IS_VALID()    lcd_gotoxy(7,1); lcd_putc('k');
#define LCD_LINES     2
#define LCD_DISP_LEN  8
#define DEBUG         0

#elif CUSTOMIZATION == default_2x16

#define SHOW_GREETING show_greeting_2x16
#define SHOW_RESULT   show_result_2x16
#define PHASE1()      lcd_gotoxy(14,1); lcd_putc('.');
#define PHASE2()      lcd_gotoxy(14,1); lcd_putc('o');
#define PHASE3()      lcd_gotoxy(14,1); lcd_putc('O');
#define UNDERFLOW()   lcd_gotoxy(15,1); lcd_putc('U')
#define IS_VALID()    lcd_gotoxy(15,1); lcd_putc('k');
#define LCD_LINES     2
#define LCD_DISP_LEN  16
#define DEBUG         0

#elif CUSTOMIZATION == debug_2x16

#define SHOW_GREETING show_greeting_debug
#define SHOW_RESULT   show_result_debug
#define PHASE1()      lcd_gotoxy(0,0)
#define PHASE2()      lcd_gotoxy(1,0)
#define PHASE3()      lcd_gotoxy(2,0)
#define UNDERFLOW()   lcd_gotoxy(3,0)
#define IS_VALID()    lcd_gotoxy(4,0)
#define LCD_LINES     2
#define LCD_DISP_LEN  16
#define DEBUG         1

#elif CUSTOMIZATION== de0508_2x16
// -------------------------------------------------------
// Beschreibung
// http://www.mikrocontroller.net/topic/200279#2291231
// -------------------------------------------------------
#define SHOW_GREETING show_greeting_de0508_2x16
#define SHOW_RESULT   show_result_de0508_2x16
                                 
#define PHASE1()      lcd_gotoxy(14,1); lcd_putc('.');
#define PHASE2()      lcd_gotoxy(14,1); lcd_putc('o');
#define PHASE3()      lcd_gotoxy(14,1); lcd_putc('O');                                                               
#define UNDERFLOW()   lcd_gotoxy(15,1); lcd_putc('#')                          
#define IS_VALID()    lcd_gotoxy(15,1); lcd_putc('k');                         
#define LCD_LINES     2                                                        
#define LCD_DISP_LEN  16                                                       
#define DEBUG         0
#else

#error "unknown CUSTOMIZATION in config.h"

#endif


#endif /* CONFIG_H */
